@@ -1,4 +1,4 @@
-### $Id: newGenerics.R,v 1.2 2001/01/10 19:04:03 bates Exp $
+### $Id: newGenerics.R,v 1.3 2001/06/18 21:16:49 bates Exp $
 ###
 ###    New generics used with corStruct, varFunc, groupedData, and reStruct
 ###
@@ -25,10 +25,6 @@ ACF <-
   ## autocorrelation function - needed not exist if acf were generic
   function(object, maxLag, ...) UseMethod("ACF")
 
-AIC <-
-  ## Return the object's value of the Aikaike Information Criterion
-  function(object, ...) UseMethod("AIC")
-
 BIC <-
   ## Return the object's value of the Bayesian Information Criterion
   function(object, ...) UseMethod("BIC")
